==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mainmenu/translations/mainmenu_da_DK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="da_DK">
<context>
    <name>RazorMainMenu</name>
    <message>
        <location filename="../razormainmenu.cpp" line="179"/>
        <source>Leave</source>
        <translation>Forlad</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="14"/>
        <source>Razor Main Menu settings</source>
        <translation>Razor Hoved Menu Indstillinger</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Vis tekst</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="45"/>
        <source>Button text</source>
        <translation>Knaptekst</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="65"/>
        <location filename="../razormainmenuconfiguration.ui" line="71"/>
        <source>Menu file</source>
        <translation>Menu konfigurationsfil</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="85"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="95"/>
        <source>Keyboard Shortcut</source>
        <translation>Tastaturgenveje</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.ui" line="101"/>
        <source>Click the button to record shortcut:</source>
        <translation>Klik for at optage genvej:</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="89"/>
        <source>Choose menu file</source>
        <translation>Vælg menu konfigurationsfil</translation>
    </message>
    <message>
        <location filename="../razormainmenuconfiguration.cpp" line="89"/>
        <source>Menu files (*.menu)</source>
        <translation>Menu konfigurationsfiler (*.menu)</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mainmenu/translations/mainmenu_da_DK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da_DK" version="2.0">
<context>
    <name>RazorMainMenu</name>
    <message>
        <source>Leave</source>
        <translation>Forlad</translation>
    </message>
</context>
<context>
    <name>RazorMainMenuConfiguration</name>
    <message>
        <source>Razor Main Menu settings</source>
        <translation>Razor Hoved Menu Indstillinger</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation>Vis tekst</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation>Knaptekst</translation>
    </message>
    <message>
        <source>Menu file</source>
        <translation>Menu konfigurationsfil</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Keyboard Shortcut</source>
        <translation>Tastaturgenveje</translation>
    </message>
    <message>
        <source>Click the button to record shortcut:</source>
        <translation>Klik for at optage genvej:</translation>
    </message>
    <message>
        <source>Choose menu file</source>
        <translation>Vælg menu konfigurationsfil</translation>
    </message>
    <message>
        <source>Menu files (*.menu)</source>
        <translation>Menu konfigurationsfiler (*.menu)</translation>
    </message>
</context>
</TS>
